import Image from "next/image";
import Link from "next/link";
import useSWR from "swr";

const fetcher = (url) => fetch(url).then((res) => res.json());

export default function Category({ limit }) {
  const { data, error } = useSWR(
    `${process.env.NEXT_PUBLIC_BASE_URL}getCategories`,
    fetcher
  );

  // if (error) return <p className="text-red-500">Error loading categories</p>;

  if (error) {
    console.error("There was an error in get category");
  }
  // Show Skeleton Loader if Data is Loading
  if (!data) {
    return (
      <div className="flex flex-wrap justify-center gap-4 sm:gap-6 md:gap-8 lg:gap-10 xl:gap-12">
        {Array.from({ length: limit || 10 }).map((_, index) => (
          <div
            key={index}
            className="flex flex-col items-center justify-center animate-pulse"
          >
            <div className="md:w-24 md:h-24 h-20 w-20 rounded-full bg-gray-200"></div>
            <p className="text-center text-gray-400 mt-2 font-semibold md:text-sm text-xs">
              Loading...
            </p>
          </div>
        ))}
      </div>
    );
  }

  const categories = limit ? data.data.slice(0, limit) : data.data;

  return (
    <div className="flex flex-wrap justify-center gap-4 sm:gap-6 md:gap-8 lg:gap-10 xl:gap-12">
      {categories.map((category) => (
        <Link
          href={"products?c=" + category.id } 
          key={category.id}
          className="flex flex-col items-center justify-center"
        >
          <div className="md:w-24 md:h-24 sm:h-20 h:w-20 h-16 w-16 rounded-full border border-gray-300">
            <Image
              src={`${process.env.NEXT_PUBLIC_IMAGE_URL + category.image}`}
              alt={category.name}
              className="w-full h-full rounded-full object-contain"
              height={96}
              width={96}
              unoptimized
            />
          </div>
          <p className="text-center text-customBlack mt-2 font-semibold md:text-sm text-xs">
            {category.name}
          </p>
        </Link>
      ))}
    </div>
  );
}
